# sphinx-gha
[![Documentation Status](https://readthedocs.org/projects/sphinx-gha/badge/?version=latest)](https://sphinx-gha.readthedocs.io/en/latest/?badge=latest)
[![CI Status](https://git.offworldcolonies.nexus/drewcassidy/sphinx-gha/badges/workflows/build.yml/badge.svg?branch=main&label=build)](https://git.offworldcolonies.nexus/drewcassidy/sphinx-gha/actions)
[![PyPI version](https://img.shields.io/pypi/v/sphinx-gha)](https://pypi.org/project/sphinx-gha/)


Sphinx extension for documenting Github-compatible actions
